flit-demo
=========

.. image:: https://img.shields.io/badge/Made%20with-Python3-brightgreen.svg
        :target: https://www.python.org/
        :alt: made-with-python

.. image:: https://img.shields.io/pypi/v/flit_demo.svg
        :target: https://pypi.python.org/pypi/flit_demo

.. image:: https://img.shields.io/badge/License-BSD%202--Clause-brightgreen.svg
        :target: https://github.com/eamontoyaa/flit_demo/blob/master/LICENSE
        :alt: License

.. image:: https://readthedocs.org/projects/flit_demo/badge/?version=latest
        :target: https://flit_demo.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

Just a test for using Flit
